@@ -27,6 +27,12 @@ class BuildController:
         if not res.status_code == 200:
             raise Exception(res.text)
 
+    @verify_credentials
+    def delete_verified(self, name):
+        res = requests.delete(f'{self.account.hq}/verified/{name}', headers=self.account.headers)
+        if not res.status_code == 200:
+            raise Exception(res.text)
+
     @verify_credentials
     def create_test(self, ident, question):
         data = dict(id=ident, question=question)
@@ -69,7 +75,7 @@ class BuildController:
         raise Exception(res.text)
 
     @verify_credentials
-    def compute_proxy(self, name: dict):
+    def compute_proxy(self, name: str):
         res = requests.post(f'{self.account.hq}/compute', json=dict(name=name), headers=self.account.headers)
         if res.status_code == 200:
             return res.json()
